@@ -78,6 +78,15 @@ class ForbiddenDirectoryLister(resource.Resource):
 
 
 class NoListingFile(static.File):
+
+    def set_expires(self, request):
+        if not self.config.debugmode:
+            # XXX: Don't provide additional resource information to error responses
+            #
+            # the HTTP RFC recommands not going further than 1 year ahead
+            expires = date.today() + timedelta(days=6*30)
+            request.setHeader('Expires', generateDateTime(mktime(expires.timetuple())))
+
     def directoryListing(self):
         return ForbiddenDirectoryLister()
 
@@ -107,6 +116,7 @@ class DataLookupDirectory(NoListingFile):
                 if resource_relpath:
                     paths = resource_relpath.split(',')
                     try:
+                        self.set_expires(request)
                         return ConcatFiles(self.config, paths)
                     except ConcatFileNotFoundError:
                         return self.childNotFound
@@ -124,6 +134,7 @@ class DataLookupDirectory(NoListingFile):
             self.putChild(path, resource)
             return resource
         else:
+            self.set_expires(request)
             return NoListingFile(filepath)
 
 
@@ -157,14 +168,6 @@ class LongTimeExpiringFile(DataLookupDirectory):
     def _defineChildResources(self):
         pass
 
-    def render(self, request):
-        # XXX: Don't provide additional resource information to error responses
-        #
-        # the HTTP RFC recommands not going further than 1 year ahead
-        expires = date.today() + timedelta(days=6*30)
-        request.setHeader('Expires', generateDateTime(mktime(expires.timetuple())))
-        return DataLookupDirectory.render(self, request)
-
 
 class ConcatFileNotFoundError(CubicWebException):
     pass
@@ -173,24 +176,38 @@ class ConcatFileNotFoundError(CubicWebException):
 class ConcatFiles(LongTimeExpiringFile):
     def __init__(self, config, paths):
         _, ext = osp.splitext(paths[0])
-        # create a unique / predictable filename
+        self._resources = {}
+        # create a unique / predictable filename. We don't consider cubes
+        # version since uicache is cleared at server startup, and file's dates
+        # are checked in debug mode
         fname = 'cache_concat_' + hashlib.md5(';'.join(paths)).hexdigest() + ext
         filepath = osp.join(config.appdatahome, 'uicache', fname)
         LongTimeExpiringFile.__init__(self, config, filepath)
         self._concat_cached_filepath(filepath, paths)
 
+    def _resource(self, path):
+        try:
+            return self._resources[path]
+        except KeyError:
+            self._resources[path] = self.config.locate_resource(path)
+            return self._resources[path]
+
     def _concat_cached_filepath(self, filepath, paths):
         if not self._up_to_date(filepath, paths):
-            concat_data = []
-            for path in paths:
-                # FIXME locate_resource is called twice() in debug-mode, but
-                # it's a @cached method
-                dirpath, rid = self.config.locate_resource(path)
-                if rid is None:
-                    raise ConcatFileNotFoundError(path)
-                concat_data.append(open(osp.join(dirpath, rid)).read())
             with open(filepath, 'wb') as f:
-                f.write('\n'.join(concat_data))
+                for path in paths:
+                    dirpath, rid = self._resource(path)
+                    if rid is None:
+                        # In production mode log an error, do not return a 404
+                        # XXX the erroneous content is cached anyway
+                        LOGGER.error('concatenated data url error: %r file '
+                                     'does not exist', path)
+                        if self.config.debugmode:
+                            raise ConcatFileNotFoundError(path)
+                    else:
+                        for line in open(osp.join(dirpath, rid)):
+                            f.write(line)
+                        f.write('\n')
 
     def _up_to_date(self, filepath, paths):
         """
@@ -203,7 +220,7 @@ class ConcatFiles(LongTimeExpiringFile):
         if self.config.debugmode:
             concat_lastmod = os.stat(filepath).st_mtime
             for path in paths:
-                dirpath, rid = self.config.locate_resource(path)
+                dirpath, rid = self._resource(path)
                 if rid is None:
                     raise ConcatFileNotFoundError(path)
                 path = osp.join(dirpath, rid)
@@ -211,6 +228,7 @@ class ConcatFiles(LongTimeExpiringFile):
                     return False
         return True
 
+
 class CubicWebRootResource(resource.Resource):
     def __init__(self, config, vreg=None):
         resource.Resource.__init__(self)
@@ -492,6 +510,7 @@ def run(config, vreg=None, debug=None):
     # serve it via standard HTTP on port set in the configuration
     port = config['port'] or 8080
     interface = config['interface']
+    reactor.suggestThreadPoolSize(config['webserver-threadpool-size'])
     reactor.listenTCP(port, website, interface=interface)
     if not config.debugmode:
         if sys.platform == 'win32':
