@@ -646,9 +646,10 @@ def guess_rrqlexpr_mainvars(expression):
 
 def split_expression(rqlstring):
     for expr in rqlstring.split(','):
-        for noparen in expr.split('('):
-            for word in noparen.split():
-                yield word
+        for noparen1 in expr.split('('):
+            for noparen2 in noparen1.split(')'):
+                for word in noparen2.split():
+                    yield word
 
 def normalize_expression(rqlstring):
     """normalize an rql expression to ease schema synchronization (avoid
@@ -1011,6 +1012,9 @@ class RepoEnforcedRQLConstraintMixIn(object):
         else:
             expression = 'S eid %(s)s, O eid %(o)s, ' + self.expression
             args = {'s': eidfrom, 'o': eidto}
+        if 'U' in self.rqlst.defined_vars:
+            expression = 'U eid %(u)s, ' + expression
+            args['u'] = session.user.eid
         rql = 'Any %s WHERE %s' % (','.join(sorted(self.mainvars)), expression)
         if self.distinct_query:
             rql = 'DISTINCT ' + rql
